/*
 * ListBean.java
 */

package com.example.web;

import java.util.List;
import java.util.Map;
import javax.faces.event.ActionEvent;
import javax.faces.context.FacesContext;
import com.example.business.CustomerCriteria;
import com.example.business.CustomerService;
import com.example.model.CustomerBO;

/**
 * ListBean: JSF backing bean.
 */
public class ListBean {
    /**
     * Holds value of property criteria.
     */
    private CustomerCriteria criteria;

    /**
     * Getter for property criteria.
     * @return Value of property criteria.
     */
    public CustomerCriteria getCriteria() {
        return this.criteria;
    }

    /**
     * Setter for property criteria.
     * @param criteria New value of property criteria.
     */
    public void setCriteria(CustomerCriteria criteria) {
        this.criteria = criteria;
    }

    /**
     * Holds value of property customerService.
     */
    private CustomerService customerService;

    /**
     * Getter for property customerService.
     * @return Value of property customerService.
     */
    public CustomerService getCustomerService() {
        return this.customerService;
    }

    /**
     * Setter for property customerService.
     * @param customerService New value of property customerService.
     */
    public void setCustomerService(CustomerService customerService) {
        this.customerService = customerService;
    }

    /**
     * Action method for find customers.
     */
    public String find() {
        try {
            customerList = customerService.findCustomer(criteria);
            return "success";
        }
        catch (Exception e) {
            return "failure";
        }
    }
    
    /**
     * Action method for select a customer.
     */
    public String select() {
        // 選択されたCustomerBOを取得する
        FacesContext context = FacesContext.getCurrentInstance();
        Map requestMap = context.getExternalContext().getRequestMap();
        CustomerBO cust = (CustomerBO)requestMap.get("customer");
        // 選択されたcustをDetailsBeanに設定する
        context.getApplication()
            .createValueBinding("#{detailsBean.customer}")
            .setValue(context, cust);
        // #{detailsBean}をsessionスコープにすれば以下でもよい．
        //detailsBean.setCustomer(cust);
        return "success";
    }

    /**
     * Action event listener for clear criteria.
     */
    public void clear(ActionEvent ev) {
        criteria.clear();
    }

    /**
     * Holds value of property customerList.
     */
    private List customerList;

    /**
     * Getter for property customerList.
     * @return Value of property customerList.
     */
    public List getCustomerList() {
        return this.customerList;
    }

    /**
     * Holds value of property detailsBean.
     */
    private DetailsBean detailsBean;

    /**
     * Getter for property detailsBean.
     * @return Value of property detailsBean.
     */
    public DetailsBean getDetailsBean() {

        return this.detailsBean;
    }

    /**
     * Setter for property detailsBean.
     * @param detailsBean New value of property detailsBean.
     */
    public void setDetailsBean(DetailsBean detailsBean) {

        this.detailsBean = detailsBean;
    }

}
